pub struct LastKnownGoodVersions {
pub timestamp: OffsetDateTime,
pub channels: HashMap<Channel, VersionInChannel>,
}Expand description
Response structure for the “last known good versions” API endpoint.
Contains the most recent version for each Chrome release channel (Stable, Beta, Dev, Canary).
Fields
timestamp: OffsetDateTimeWhen this data was last updated.
channels: HashMap<Channel, VersionInChannel>The latest known good version for each release channel.
Implementations
Sourceimpl LastKnownGoodVersions
impl LastKnownGoodVersions
Sourcepub async fn fetch(client: Client) -> Result<Self>
pub async fn fetch(client: Client) -> Result<Self>
Fetches the last known good versions from the Chrome for Testing API.
Returns the most recent version for each Chrome release channel (Stable, Beta, Dev, Canary).
pub async fn fetch_with_base_url( client: Client, base_url: Url, ) -> Result<LastKnownGoodVersions>