pub enum Platform {
Linux64,
MacArm64,
MacX64,
Win32,
Win64,
}Expand description
Supported platforms for Chrome and ChromeDriver downloads.
This site https://googlechromelabs.github.io/chrome-for-testing/ show the platform names defined here.
Variants
Linux64
Linux x64 platform.
MacArm64
macOS ARM64 platform (Apple Silicon).
MacX64
macOS x64 platform (Intel).
Win32
Windows 32-bit platform.
Win64
Windows 64-bit platform.
Implementations
Sourceimpl Platform
impl Platform
Sourcepub fn detect() -> Result<Platform>
pub fn detect() -> Result<Platform>
Detect the platform identifier that should be used for the current system.
Errors
Returns an error if the current OS/architecture combination is not supported.
Sourcepub fn chrome_executable_name(self) -> &'static str
pub fn chrome_executable_name(self) -> &'static str
Filename of the Chrome executable.
Sourcepub fn chrome_executable_path(self) -> &'static Path
pub fn chrome_executable_path(self) -> &'static Path
Relative path of the Chrome executable inside the unpacked Chrome archive.
Sourcepub fn chromedriver_executable_name(self) -> &'static str
pub fn chromedriver_executable_name(self) -> &'static str
Filename of the ChromeDriver executable.
Sourcepub fn chromedriver_executable_path(self) -> &'static Path
pub fn chromedriver_executable_path(self) -> &'static Path
Relative path of the ChromeDriver executable inside the unpacked ChromeDriver archive.
Sourcepub fn chrome_headless_shell_executable_name(self) -> &'static str
pub fn chrome_headless_shell_executable_name(self) -> &'static str
Filename of the Chrome Headless Shell executable.
Sourcepub fn chrome_headless_shell_executable_path(self) -> &'static Path
pub fn chrome_headless_shell_executable_path(self) -> &'static Path
Relative path of the Chrome Headless Shell executable inside the unpacked Chrome Headless Shell archive.
Sourcepub fn is_windows(&self) -> bool
pub fn is_windows(&self) -> bool
Tells whether this platform identifier references the Windows OS.